(***********************************************************************)
(*                                                                     *)
(*                             Active-DVI                              *)
(*                                                                     *)
(*                   Projet Cristal, INRIA Rocquencourt                *)
(*                                                                     *)
(*  Copyright 2002 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  All rights reserved.  This file is distributed    *)
(*  under the terms of the GNU Lesser General Public License.          *)
(*                                                                     *)
(*  Jun Furuse, Didier Rmy and Pierre Weis.                           *)
(*  Contributions by Roberto Di Cosmo, Didier Le Botlan,               *)
(*  Xavier Leroy, and Alan Schmitt.                                    *)
(*                                                                     *)
(*  Based on Mldvi by Alexandre Miquel.                                *)
(***********************************************************************)

(* $Id: dviview.mli,v 1.18 2003/10/28 12:43:28 remy Exp $ *)

open Dimension;;
val set_autoresize : bool -> unit;;
val set_autoscale : bool -> unit;;
val set_geometry : string -> unit;;
val set_crop : bool -> unit;;
val set_hmargin : dimen -> unit;;
val set_vmargin : dimen -> unit;;

exception Error of string;;

val main_loop : string -> string list -> unit;;
